text package
============

text.classify module
------------------------------------

.. automodule:: text.classify
   :members:
   :undoc-members:
   :show-inheritance:

text.defaults module
------------------------------------

.. automodule:: text.defaults
   :members:
   :undoc-members:
   :show-inheritance:


text.nlp_utils module
------------------------------------

.. automodule:: text.nlp_utils
   :members:
   :undoc-members:
   :show-inheritance:

text.preprocess module
------------------------------------

.. automodule:: text.preprocess
   :members:
   :undoc-members:
   :show-inheritance:

text.utils module
------------------------------------

.. automodule:: text.utils
   :members:
   :undoc-members:
   :show-inheritance:

text.visualize module
------------------------------------

.. automodule:: text.visualize
   :members:
   :undoc-members:
   :show-inheritance:
